import { useToast } from "../hooks";
import { get, post } from "../utils/axios";

const networkRoute = `${process.env.REACT_APP_NETWORK_RESURRECTOR_API_URL}/network`;
const powerActionsRoute = `${process.env.REACT_APP_NETWORK_RESURRECTOR_API_URL}/resurrector`;

const useApi = () => {
  const { error } = useToast();

  const handleError = err => {
    let message;
    switch (err.response?.status) {
      case 500:
        message = err.response.statusText;
        break;

      default:
        message = err.message;
    }

    error(message);
  };

  const defaultOptions = { onCompleted: () => {}, onError: handleError };

  const call = async (request, options) => {
    const internalOptions = { ...defaultOptions, ...options };
    const { onCompleted, onError } = internalOptions;

    try {
      const result = await request();
      onCompleted(result);
    } catch (error) {
      onError(error);
    }
  };

  const readMachines = (options = defaultOptions) => {
    const machinesPromise = call(
      () => get(`${networkRoute}/machines`),
      options
    );
    return machinesPromise;
  };

  const wakeMachine = (machineId, options = defaultOptions) => {
    const promise = call(
      () => post(`${powerActionsRoute}/wake`, { machineId }),
      options
    );
    return promise;
  };

  const pingMachine = (machineId, options = defaultOptions) => {
    const promise = call(
      () => post(`${powerActionsRoute}/ping`, { machineId }),
      options
    );
    return promise;
  };

  return { readMachines, wakeMachine, pingMachine };
};

export default useApi;
