import React, { useState, useCallback } from "react";
import PropTypes from "prop-types";
import Machine from "./Machine";
import { useToast } from "../../../hooks";
import { LastPage } from "@material-ui/icons";
import { useTranslation } from "react-i18next";
import useApi from "../../../api";

const MachineContainer = ({ machine }) => {
  const [logs, setLogs] = useState([]);
  const { success, error } = useToast();
  const { t } = useTranslation();

  const api = useApi();

  const addLog = useCallback(
    text => {
      setLogs(prev => [...prev, text]);
    },
    [setLogs]
  );

  const pingMachine = useCallback(
    machine => async () => {
      await api.pingMachine(machine.machineId, {
        onCompleted: result => {
          addLog(`Success: ${result.success}. Status: ${result.status}`);
          if (result.success) {
            success(result.status);
          } else {
            error(result.status);
          }
        }
      });
    },
    [error, success, addLog, api]
  );

  const actions = [
    {
      code: "ping",
      effect: pingMachine,
      icon: LastPage,
      tooltip: t("Machine.Actions.Ping")
    }
  ];

  return (
    <Machine machine={machine} actions={actions} logs={logs} addLog={addLog} />
  );
};

MachineContainer.propTypes = {
  machine: PropTypes.object.isRequired
};

export default MachineContainer;
